/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi

import org.junit.jupiter.api.Assertions.fail

trait ScalaAssertionSupport {

  def assertThrows[T <: Throwable, R](expectedExceptionClass: Class[T])(f: => R): T = {
    try {
      f
    } catch {
      case t: Throwable if expectedExceptionClass.isAssignableFrom(t.getClass) =>
        // scalastyle:off return
        return t.asInstanceOf[T]
      // scalastyle:on return
      case ot : Throwable =>
        fail(s"Expected exception of class $expectedExceptionClass, but ${ot.getClass} has been thrown: $ot\n${ot.getStackTrace.mkString("\n")}")
    }

    fail(s"Expected exception of class $expectedExceptionClass, but nothing has been thrown")
  }
}
